@@ -18,7 +18,9 @@
 #include <unordered_map>
 #include <vector>
 
+#include "hwy/aligned_allocator.h"  // IsAligned
 #include "hwy/base.h"
+#include "hwy/contrib/sort/vqsort.h"
 #include "hwy/detect_compiler_arch.h"
 
 // clang-format off
@@ -26,26 +28,15 @@
 #define HWY_TARGET_INCLUDE "hwy/contrib/sort/sort_unit_test.cc"  // NOLINT
 // clang-format on
 #include "hwy/foreach_target.h"  // IWYU pragma: keep
-// After foreach_target
-#include "hwy/aligned_allocator.h"  // IsAligned
+#include "hwy/highway.h"
+// After highway.h
 #include "hwy/contrib/sort/algo-inl.h"
 #include "hwy/contrib/sort/result-inl.h"
 #include "hwy/contrib/sort/traits128-inl.h"
 #include "hwy/contrib/sort/vqsort-inl.h"  // BaseCase
-#include "hwy/contrib/sort/vqsort.h"
-#include "hwy/highway.h"
 #include "hwy/print-inl.h"
 #include "hwy/tests/test_util-inl.h"
 
-// TODO(b/314758657): Compiler bug causes incorrect results on SSE2/S-SSE3.
-#undef VQSORT_SKIP
-#if !defined(VQSORT_DO_NOT_SKIP) && HWY_COMPILER_CLANG && HWY_ARCH_X86 && \
-    HWY_TARGET >= HWY_SSSE3
-#define VQSORT_SKIP 1
-#else
-#define VQSORT_SKIP 0
-#endif
-
 HWY_BEFORE_NAMESPACE();
 namespace hwy {
 namespace HWY_NAMESPACE {
@@ -310,7 +301,7 @@ static HWY_NOINLINE void TestBaseCase() {
 
 HWY_NOINLINE void TestAllBaseCase() {
   // Workaround for stack overflow on MSVC debug.
-#if defined(_MSC_VER) || VQSORT_SKIP
+#if defined(_MSC_VER)
   return;
 #endif
 
@@ -558,8 +549,8 @@ static void TestAllGenerator() {}
 HWY_AFTER_NAMESPACE();
 
 #if HWY_ONCE
-
 namespace hwy {
+namespace {
 HWY_BEFORE_TEST(SortTest);
 HWY_EXPORT_AND_TEST_P(SortTest, TestAllFloatLargerSmaller);
 HWY_EXPORT_AND_TEST_P(SortTest, TestAllFloatInf);
@@ -568,6 +559,7 @@ HWY_EXPORT_AND_TEST_P(SortTest, TestAllBaseCase);
 HWY_EXPORT_AND_TEST_P(SortTest, TestAllPartition);
 HWY_EXPORT_AND_TEST_P(SortTest, TestAllGenerator);
 HWY_AFTER_TEST();
+}  // namespace
 }  // namespace hwy
-
+HWY_TEST_MAIN();
 #endif  // HWY_ONCE
